/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.dao.content');

/**
 * @class This class is the representation of a content. Do not keep it for a long time: informations can be obsoletes. 
 */

/**
 * Do not call this method. 
 * To get a content use the ContentDAO 
 * @constructor
 * @private
 * @param {Node} node The node sent by /plugins/web/repository/content-info
 */
org.ametys.dao.content.WebContent = function(node)
{	
	org.ametys.dao.content.WebContent.superclass.constructor.call(this, node);
	
	this._webContent = node.getAttribute("webContent") != null ? node.getAttribute("webContent") == 'true' : false;
	this._siteName = node.getAttribute("siteName"); 
	this._siteTitle = node.getAttribute("siteTitle"); 

	this._tags = {};
	var tagsNodes = node.selectNodes ('tags/tag');
	for (var j=0; j < tagsNodes.length; j++)
	{
		this._tags[tagsNodes[j][org.ametys.servercomm.ServerComm.xmlTextContent]] = true;
	}
}

Ext.extend(org.ametys.dao.content.WebContent, org.ametys.dao.content.Content, {});

/**
 * @private
 * @property {boolean} _webContent True if the content is a webcontent, false otherwise
 */
org.ametys.dao.content.WebContent.prototype._webContent;

/**
 * @private
 * @property {String} _siteName The name of the site of the content (if webcontent)
 */
org.ametys.dao.content.WebContent.prototype._siteName;
/**
 * @private
 * @property {String} _siteTitle The title of the site of the content (if webcontent)
 */
org.ametys.dao.content.WebContent.prototype._siteTitle;

/**
 * @private
 * @property {Map<String,boolean>} A set of the id of the tags on this content. The boolean is always true.
 */
org.ametys.dao.content.Content.prototype._tags;

/**
 * Determine if the content is stored as a web content
 * @return {boolean} True if the content is a webcontent, false otherwise
 */
org.ametys.dao.content.WebContent.prototype.isWebContent = function()
{
	return this._webContent;
}

/**
 * Get the attached site's name
 * @return {String} The name of the site of the content (if webcontent)
 */
org.ametys.dao.content.WebContent.prototype.getSiteName = function()
{
	return this._siteName;
}

/**
 * Get the attached site's title
 * @return {String} The title of the site of the content (if webcontent)
 */
org.ametys.dao.content.WebContent.prototype.getSiteTitle = function()
{
	return this._siteTitle;
}

/**
 * Get the set of the tags on this content
 * @return {Map<String,boolean>} The set of ids of tags. Do not modify it!
 */
org.ametys.dao.content.Content.prototype.getTags = function()
{
	return this._tags;
}

/**
 * Determine if the current content has the specified tag
 * @param {String} tagId The identifier of the tag to check
 * @return {boolean} True or false
 */
org.ametys.dao.content.Content.prototype.hasTag = function(tagId)
{
	return this._tags[tagId] == true;
}

/**
 * Add all the attributes to the given map
 * @param {Map<String,Object>} map The non null map
 */
org.ametys.dao.content.WebContent.prototype.toMap = function(map)
{
	org.ametys.dao.content.WebContent.superclass.toMap.call(this, map);
	
	map['webContent'] = this.isWebContent() ? "true" : "false"; 
	map['siteName'] = this.getSiteName(); 
	map['siteTitle'] = this.getSiteTitle(); 

	var tags = [];
	for (var tag in this.getTags())
	{
		tags.push (tag);
	}
	map['tags'] = tags;
}
