/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Enable or disable alias reordering buttons depending on the alias position.
 */
org.ametys.ribbon.control.button.AliasMoveButton = function(id, configuration, pluginName)
{
    org.ametys.ribbon.control.button.AliasMoveButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.AliasMoveButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

org.ametys.ribbon.control.button.AliasMoveButton.prototype.onMessage = function(messages)
{
    for (var i = messages.length-1; i >= 0; i--)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
        {
            var allTargets = messages[i].getTargets();
            var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, this._testTarget.createDelegate(this));
            
            if (targets.length == 1 && this._testAlias(targets[0]))
            {
                this.getElements().each(function(element) { element.enable(); });
            }
            else
            {
                this.getElements().each(function(element) { element.disable(); });
            }
        }
    }
}

/**
 * Test an alias on a button.
 * @return {org.ametys.messagebus.message.MessageTarget} The target to check
 * @private
 */
org.ametys.ribbon.control.button.AliasMoveButton.prototype._testAlias = function(target)
{
    var aliasEnabled = false;
    
    var id = target.getParameters().id;
    var previousId = target.getParameters().previousAliasId;
    var nextId = target.getParameters().nextAliasId;
    if (this.getConfiguration()['direction'] == 'up' && previousId != null)
    {
        aliasEnabled = true;
    }
    else if (this.getConfiguration()['direction'] == 'down' && nextId != null)
    {
        aliasEnabled = true;
    }
    
    return aliasEnabled;
}
