/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance. The control is enable if according to the state of the application.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.button.ExplorerApplicationButton
 */
org.ametys.ribbon.control.button.ExplorerApplicationStateButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.ExplorerApplicationStateButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.ExplorerApplicationStateButton, org.ametys.ribbon.control.button.ActionButton, {});

org.ametys.ribbon.control.button.ExplorerApplicationStateButton.prototype.onMessage = function (messages)
{
	for (var i=messages.length-1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLFOCUSES)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "tool"});
			var currentToolId = target.getParameters()['id'];
				
			if (this.getConfiguration()['tool-id'] != null && currentToolId == this.getConfiguration()['tool-id'])
			{
				this.getElements().each(function (element) { element.enable(); });
				return;
			}
		}
		
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLFOCUSES
			|| messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLBLUR)
		{
			this.getElements().each(function (element) { element.disable(); });
		}
		
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLSTATECHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "tool"});
				
			if (this.getConfiguration()['tool-id'] != null && target.getParameters()['id'] == this.getConfiguration()['tool-id'])
			{
				var tool = org.ametys.uitool.ToolsManager.getInstance().getTool(this.getConfiguration()['tool-id']);
				var app = tool.getExplorer().getApplication(this.getConfiguration()['application-id']);
				if (app != null)
				{
					var toggle = app.queryCommandState (this.getConfiguration()['command-state'], {view: this.getConfiguration()['state']});
					this.getElements().each(function(element) { element.toggle(toggle); })
					return;
				}
			}
			
			this.getElements().each(function(element) { element.toggle(false); })
		}
	}
}