/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @class This class provides an {@link org.ametys.ribbon.control.button.ActionButton} which is enabled if the selection is an editable resource explorer node
 * @extends {@link org.ametys.ribbon.control.button.ActionButton}
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @constructor
 */
org.ametys.ribbon.control.button.ModifiableResourceButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.ModifiableResourceButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.ModifiableResourceButton, org.ametys.ribbon.control.button.RightActionSelectionButton, {});

org.ametys.ribbon.control.button.ModifiableResourceButton.prototype.onMessage = function (messages)
{
	for (var i=messages.length-1; i >=0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));
			
			if (target != null)
			{
				if (!target.getParameters().isModifiable)
				{
					var text = this._getTooltip(this.getConfiguration()["no-modifiable-description"]);
					this.updateTooltip(text, null, null);
					
					this.getElements().each(function(element) {element.disable();});
				}
				else if (!this._hasRight(target))
				{
					var text = this._getTooltip(this.getConfiguration()["no-right-description"]);
					this.updateTooltip(text, null, null);
					
					this.getElements().each(function(element) {element.disable();});
				}
				else
				{
					this.getElements().each(function(element) {element.enable();});
					
					this.updateTooltip(this.getConfiguration()["default-description"], null, null);
				}
			}
			else
			{
				var text = this._getTooltip(this.getConfiguration()["no-selection-description"]);
				this.updateTooltip(text, null, null);
				this.getElements().each(function(element) {element.disable();});
			}
		}
	}
}

org.ametys.ribbon.control.button.ExplorerNodeButton.prototype._isDisabled = function (target)
{
	
	return target.getParameters()['applicationId'] != this.getConfiguration()['application-id'];
}


