/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance. Special configuration is "sitemap" true or false to include sitemap as a correct selection.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.RibbonControl
 */
org.ametys.ribbon.control.button.ModifiableZoneItemActionButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.ModifiableZoneItemActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.ModifiableZoneItemActionButton, org.ametys.ribbon.control.button.ZoneItemActionButton, {});

/**
 * Creates the toggle button
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.ribbon.control.button.ModifiableZoneItemActionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			
			var pageTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) {return target.getType() == "page"} );
			if (pageTarget != null && pageTarget.getParameters()["type"] == "container" && pageTarget.getParameters()["zoneitem-id"] != null)
			{
				var zoneItemId = pageTarget.getParameters()["zoneitem-id"];
				var zoneItemTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(pageTarget.getSubTargets(), function(target) {return target.getType() == "zoneitem" && target.getParameters().id == zoneItemId} );
				
				if (zoneItemTarget != null && zoneItemTarget.getParameters().isModifiable != 'true')
				{
					var text = this._getTooltip(this.getConfiguration()["no-modifiable-description"]);
					this.updateTooltip(text, null, null);
					this.getElements().each(function(element) {element.disable();});
				}
				else if (this._hasRight(pageTarget))
				{
					this.updateTooltip(this._getTooltip(), null, null);
					this.getElements().each(function(element) { element.enable(); })
				}
				else
				{
					this.updateTooltip(this._getTooltip(this.getConfiguration()["no-right-description"]), null, null);
					this.getElements().each(function(element) { element.disable(); })
				}
			}
			else
			{
				this.updateTooltip(this._getTooltip(this.getConfiguration()["no-selection-description"]), null, null);
				this.getElements().each(function(element) { element.disable(); })
			}
		}
	}
}
