/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.web.tool.page');

org.ametys.web.tool.page.PasteMenu = function(id, configuration, pluginName) 
{
	org.ametys.web.tool.page.PasteMenu.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.web.tool.page.PasteMenu, org.ametys.cms.ribbon.button.Menu, {});

org.ametys.web.tool.page.PasteMenu.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function (target) { return target.getType() == 'page' || target.getType() == 'sitemap'; } );
			
			if (target != null)
			{
				if (!this._hasRight(target))
				{
					var text = this._getTooltip(this.getConfiguration()["no-right-description"]);
					this.updateTooltip(text, null, null);
					
					this.getElements().each(function(element) {element.disable();});
				}
				else
				{
					var parent = this;
					this.getElements().each(function(button) {
						for (var itemId in button._menuItems)
						{
							var item = button._menuItems[itemId];
							item.setDisabled(!parent._hasRight(target, itemId + '-right-id'));
						}
					});
					
					this.getElements().each(function(element) {element.enable();});
					
					this.updateTooltip(this.getConfiguration()["default-description"], null, null);
				}
			}
			else
			{
				var text = this._getTooltip(this.getConfiguration()["no-selection-description"]);
				this.updateTooltip(text, null, null);
				this.getElements().each(function(element) {element.disable();});
			}
		}
	}
}

/**
 * Checks the user right
 * @return true if the user has right to do the action
 * @private
 */
org.ametys.web.tool.page.PasteMenu.prototype._hasRight = function(target, id)
{
	id = id || 'right-id';

	if (!this.getConfiguration()[id])
	{
		// No right is needed
		return true;
	}
	
	var neededRights = this.getConfiguration()[id].split('|');
	
	var rights = target.getParameters().rights;
	for (var i=0;  rights != null && i < rights.length; i++)
	{
		if (neededRights.indexOf(rights[i]) != -1)
		{
			return true;
		}
	}
	return false;
}

org.ametys.web.tool.page.PasteMenu.prototype._getTooltip = function (addedText)
{
	var tooltip = this.getConfiguration()["default-description"];
	if (addedText != null && addedText.length > 0)
	{
		tooltip += "<br/><br/>";
		
		tooltip += addedText;
	}
	return tooltip;
}
