/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.web.tree');

org.ametys.web.tree.SitemapXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.web.tree.SitemapXmlLoader.prototype.processAttributes = function (attr)
{
	org.ametys.web.tree.SitemapXmlLoader.superclass.processAttributes.call(this, attr);
	
	if (attr.tagName == 'site')
	{
		attr.type = 'site';
		attr.text = attr.title;
		attr.allowChildren = false;
		attr.icon = getPluginResourcesUrl('web') + '/img/root.png';
	}
	else if (attr.tagName == 'sitemap')
	{
		attr.type = 'sitemap';
		attr.text = attr.name;
		attr.allowChildren = false;
		attr.icon = getPluginResourcesUrl('web') + '/img/flag/flag_' + attr.name + '.gif';
	}
	else
	{
		attr.cls = 'x-tree-page-validated',
		attr.type = 'page';
		attr.text = attr.title;
		attr.icon = attr.icon ? context.contextPath + attr.icon : getPluginResourcesUrl('web') + '/img/page_16.png';
		attr.allowChildren = true;
		if (!attr.hasChild)
		{
			attr.leaf = true;
		}
		
		if (this.checkMode)
        {
       	 	attr.checked = false;
        }
	}
}

/**
 * Override createNode function to always return a AsyncTreeNode
 */
org.ametys.web.tree.SitemapXmlLoader.prototype.createNode = function(node)
{
	var attr = {
		tagName: node.tagName
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});
	
	this._currentXMLNode = node;
	
	var decorators = node.selectNodes("decorator");
	for (var i=0; i < decorators.length; i++)
	{
		attr['decorator_' + decorators[i].getAttribute('id')] =  context.contextPath + decorators[i].getAttribute('icon');
		attr['decorator_' + decorators[i].getAttribute('id') + '.label'] =  decorators[i][org.ametys.servercomm.ServerComm.xmlTextContent];
	}
	
	this.processAttributes(attr);
	delete 	this._currentXMLNode;
		
    if(this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if(this.applyLoader !== false)
    {
        attr.loader = this;
    }
    if(typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
    attr.expandable = false;
    if(attr.nodeType)
    {
        return new Ext.tree.TreePanel.nodeTypes[attr.nodeType](attr);
    }
    else
    {
    	return new Ext.tree.AsyncTreeNode(attr);
    }
}

// Turn off the expanding/collapsing behavior on double click event
Ext.tree.TreeNodeUI.prototype.onDblClick = function(e){
    e.preventDefault();
    if(this.disabled){
        return;
    }
    if(this.checkbox){
        this.toggleCheck();
    }
    /*if(!this.animating && this.node.hasChildNodes()){
        this.node.toggle();
    }*/
    this.fireEvent("dblclick", this.node, e);
};
